import requests
from .exceptions import RateLimit

class getItem():
    def __init__(self, id):
        itemdetails = requests.get("https://www.rolimons.com/itemapi/itemdetails").json()
        if not itemdetails['success']:
            raise RateLimit('Rate limit exceeded')
        # [item_name, acronym, rap, value, default_value, demand, trend, projected, hyped, rare]

        self.id = str(id)
        self.name = itemdetails['items'][str(id)][0]
        self.acronym = itemdetails['items'][str(id)][1]
        self.rap = itemdetails['items'][str(id)][2]
        self.value = itemdetails['items'][str(id)][3]
        self.default_value = itemdetails['items'][str(id)][4]
        self.demand = itemdetails['items'][str(id)][5]
        self.trend = itemdetails['items'][str(id)][6]
        self.projected = itemdetails['items'][str(id)][7]
        self.hyped = itemdetails['items'][str(id)][8]
        self.rare = itemdetails['items'][str(id)][9]

class getLimiteds(): # raw = True
    def __init__(self):
        itemdetails = requests.get("https://www.rolimons.com/itemapi/itemdetails").json()
        if not itemdetails['success']:
            raise RateLimit('Rate limit exceeded')
        # [item_name, acronym, rap, value, default_value, demand, trend, projected, hyped, rare]

        self.id = [str(item) for item in itemdetails['items']]
        self.name = [itemdetails['items'][str(item)][0] for item in itemdetails['items']]
        self.acronym = [itemdetails['items'][str(item)][1] for item in itemdetails['items']]
        self.rap = [itemdetails['items'][str(item)][2] for item in itemdetails['items']]
        self.value = [itemdetails['items'][str(item)][3] for item in itemdetails['items']]
        self.default_value = [itemdetails['items'][str(item)][4] for item in itemdetails['items']]
        self.demand = [itemdetails['items'][str(item)][5] for item in itemdetails['items']]
        self.trend = [itemdetails['items'][str(item)][6] for item in itemdetails['items']]
        self.projected = [itemdetails['items'][str(item)][7] for item in itemdetails['items']]
        self.hyped = [itemdetails['items'][str(item)][8] for item in itemdetails['items']]
        self.rare = [itemdetails['items'][str(item)][9] for item in itemdetails['items']]



import requests
import datetime
from .exceptions import *

class getPlayer():
    def __init__(self, player = None):
        if str(player).isdigit():
            self.id = str(player)
            self.getPlayerInfo(self.id)
        else:
            request = requests.get(f'https://api.rolimons.com/players/v1/playersearch?searchstring={player}').json()
            if not request['success']:
                raise RateLimit('Rate limit exceeded')

            if request['players']:
                for index, item in enumerate(request['players']):
                    if player.lower() == item[1].lower():
                        self.id = item[0]
                        self.getPlayerInfo(self.id)
                        break
                    else:
                        if index == len(request['players']) - 1:
                            raise PlayerNotFound(f'Player {player} not found!')
            else:
                raise PlayerNotFound(f'Player {player} not found!')

    def getPlayerInfo(self, id):
        request = requests.get(f'https://api.rolimons.com/players/v1/playerinfo/{id}').json()
        self.name = request['name']
        self.value = request['value']
        self.rap = request['rap']
        self.rank = request['rank']
        self.premium = request['premium']
        self.privacy_enabled = request['privacy_enabled']
        self.terminated = request['terminated']
        self.stats_updated = request['stats_updated']
        self.stats_updated_utc = datetime.datetime.utcfromtimestamp(self.stats_updated)
        self.last_scan = request['last_scan']
        self.last_scan_utc = datetime.datetime.utcfromtimestamp(self.last_scan)
        self.last_online = request['last_online']
        self.last_online_utc = datetime.datetime.utcfromtimestamp(self.last_online)
        self.last_location = request['last_location']



from setuptools import setup, find_packages
from pathlib import Path
import codecs
import os

VERSION = '0.1.2'
DESCRIPTION = "API Wrapper for Rolimon's"
this_directory = Path(__file__).parent
LONG_DESCRIPTION = (this_directory / "README.md").read_text()   # "rolilib is an open source API Wrapper for Rolimon's"

# Setting up
setup(
    name="rolilib",
    version=VERSION,
    author="ThunderFound",
    author_email="<contact.thunderfound@gmail.com>",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=LONG_DESCRIPTION,
    packages=find_packages(),
    install_requires=['requests', 'datetime'],
    keywords=['python', 'api', 'rolimons'],
    classifiers=[
        "Programming Language :: Python :: 3",
    ]
)